@@ -11,7 +11,7 @@
 import re
 import inspect
 
-__version__ = '0.4'
+__version__ = '0.4.1'
 __author__ = 'Hsiaoming Yang <me@lepture.com>'
 __all__ = [
     'BlockGrammar', 'BlockLexer',
@@ -98,7 +98,7 @@ class BlockGrammar(object):
     )
     hrule = re.compile(r'^(?: *[-*_]){3,} *(?:\n+|$)')
     heading = re.compile(r'^ *(#{1,6}) *([^\n]+?) *#* *(?:\n+|$)')
-    lheading = re.compile(r'^([^\n]+)\n *(=|-){2,} *(?:\n+|$)')
+    lheading = re.compile(r'^([^\n]+)\n *(=|-)+ *(?:\n+|$)')
     block_quote = re.compile(r'^( *>[^\n]+(\n[^\n]+)*\n*)+')
     list_block = re.compile(
         r'^( *)([*+-]|\d+\.) [\s\S]+?'
@@ -417,9 +417,9 @@ class InlineGrammar(object):
 
     escape = re.compile(r'^\\([\\`*{}\[\]()#+\-.!_>~|])')  # \* \+ \! ....
     tag = re.compile(
-        r'^<!--[\s\S]*?-->|'
-        r'^<\/?\w+(?:"[^"]*"|'
-        r'''[^']*'|[^'">])*?>'''
+        r'^<!--[\s\S]*?-->|'  # comment
+        r'^<\/\w+>|'  # close tag
+        r'^<\w+[^>]*?>'  # open tag
     )
     autolink = re.compile(r'^<([^ >]+(@|:\/)[^ >]+)>')
     link = re.compile(
@@ -889,6 +889,7 @@ class Markdown(object):
             self.inline = InlineLexer(renderer, rules=rules)
 
         self.block = block or BlockLexer(BlockGrammar())
+        self.options = kwargs
         self.footnotes = []
         self.tokens = []
 
@@ -1052,6 +1053,8 @@ class Markdown(object):
 
     def parse_block_html(self):
         text = self.token['text']
+        if self.options.get('parse_html') and not self.token.get('pre'):
+            text = self.inline(text)
         return self.renderer.block_html(text)
 
     def parse_paragraph(self):
